/*
 * Copyright (C) 2010 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by Neil Jagdish Patel <neil.patel@canonical.com>
 *
 */

using Unity.Places;

public class Main
{
  private const string name  = "com.canonical.Unity.Place.Applications";
  private const string path  = "/com/canonical/Unity/Place/Applications";
  private const string iface = "com.canonical.Unity.Place";

  public static int main (string[] args)
  {
    MainLoop        loop;
    DBus.Connection conn;

    loop= new MainLoop (null, false);

    print ("%s %s %s\n", Config.PKGDATADIR, Config.LOCALE_DIR, Config.GETTEXT_PACKAGE);

    /* Let's see if we can grab our name */
    try
      {
        dynamic DBus.Object bus;

        conn = DBus.Bus.get (DBus.BusType.SESSION);

        bus = conn.get_object ("org.freedesktop.DBus",
                               "/org/freedesktop/DBus",
                               "org.freedesktop.DBus");

        uint res = bus.request_name (name, (uint)0);

        if (res != DBus.RequestNameReply.PRIMARY_OWNER)
          {
            warning (@"Cannot become primary name owner for $name, quitting");
            return 1;
          }
      }
    catch (Error e)
      {
        warning (@"Unable to grab $name: %s", e.message);
        return 1;
      }

    var place = new Applications ();
    Utils.register_object_on_dbus (conn, path, place);

    loop.run ();

    return 0;
  }
}
